
# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: PythonLibrary(BuildFileAddress(caustic-compiler/src/main/pants/BUILD, pants))

from setuptools import setup

setup(**
{   'author': 'Ashwin Madavan',
    'author_email': 'ashwin.madavan@gmail.com',
    'classifiers': [   'Intended Audience :: Developers',
                       'License :: OSI Approved :: Apache Software License',
                       'Operating System :: OS Independent',
                       'Programming Language :: Python'],
    'description': 'Caustic plugin for Pants',
    'install_requires': [],
    'license': 'Apache License, Version 2.0',
    'name': 'caustic.pants',
    'package_data': {   },
    'package_dir': {   '': 'src'},
    'packages': [   'caustic',
                    'caustic.pants',
                    'caustic.pants.targets',
                    'caustic.pants.tasks'],
    'url': 'https://github.com/ashwin153/caustic',
    'version': '1.0.6',
    'zip_safe': True}
)
